searchData={"items":[{"type":"module","title":"ExPorterSDK","doc":"An Elixir SDK for Porter's delivery API, providing a simple and reliable way to integrate\nPorter's logistics services into your Elixir applications.","ref":"ExPorterSDK.html"},{"type":"module","title":"Features - ExPorterSDK","doc":"* Get delivery quotes based on locations\n  * Create and manage delivery orders\n  * Track order status in real-time\n  * Cancel existing orders\n  * Comprehensive test helpers and stubs","ref":"ExPorterSDK.html#module-features"},{"type":"module","title":"Installation - ExPorterSDK","doc":"Add `ex_porter_sdk` to your list of dependencies in `mix.exs`:\n\n    def deps do\n      [\n        {:ex_porter_sdk, \"~> 0.1.0\"}\n      ]\n    end","ref":"ExPorterSDK.html#module-installation"},{"type":"module","title":"Configuration - ExPorterSDK","doc":"Configure the SDK in your `config.exs` or appropriate environment config file:\n\n    config :ex_porter_sdk,\n      base_url: System.get_env(\"PORTER_BASE_URL\", \"https://api.porter.in\"),\n      api_key: System.get_env(\"PORTER_API_KEY\"),\n      quote_impl: ExPorterSDK.Quote.Impl,  # Optional, defaults to Impl\n      order_impl: ExPorterSDK.Order.Impl   # Optional, defaults to Impl","ref":"ExPorterSDK.html#module-configuration"},{"type":"module","title":"Basic Usage - ExPorterSDK","doc":"","ref":"ExPorterSDK.html#module-basic-usage"},{"type":"module","title":"Get Delivery Quote - ExPorterSDK","doc":"params = %{\n      pickup_details: %{lat: 12.909728534457143, lng: 77.6001397394293},\n      drop_details: %{lat: 12.89795704454522, lng: 77.62119799020186},\n      customer: %{\n        name: \"Test User\",\n        mobile: %{number: \"7678139714\", country_code: \"+91\"}\n      }\n    }\n\n    case ExPorterSDK.Quote.get_quote(params) do\n      {:ok, response} ->\n        # Handle successful response\n        IO.inspect(response[\"vehicles\"])\n\n      {:error, error} ->\n        # Handle error\n        IO.inspect(error)\n    end","ref":"ExPorterSDK.html#module-get-delivery-quote"},{"type":"module","title":"Create Order - ExPorterSDK","doc":"order_params = %{\n      request_id: \"unique-request-id\",\n      delivery_instructions: %{\n        instructions_list: [\n          %{type: \"text\", description: \"handle with care\"}\n        ]\n      },\n      pickup_details: %{\n        address: %{\n          apartment_address: \"27\",\n          street_address1: \"Main Street\",\n          city: \"Bengaluru\",\n          state: \"Karnataka\",\n          pincode: \"560029\",\n          country: \"India\",\n          lat: 12.939391726766775,\n          lng: 77.62629462844717,\n          contact_details: %{\n            name: \"Test User\",\n            phone_number: \"+911234567890\"\n          }\n        }\n      },\n      drop_details: %{\n        # Similar structure as pickup_details\n      }\n    }\n\n    {:ok, order} = ExPorterSDK.Order.create(order_params)","ref":"ExPorterSDK.html#module-create-order"},{"type":"module","title":"Track Order - ExPorterSDK","doc":"{:ok, status} = ExPorterSDK.Order.track(\"order_id\")","ref":"ExPorterSDK.html#module-track-order"},{"type":"module","title":"Cancel Order - ExPorterSDK","doc":"{:ok, response} = ExPorterSDK.Order.cancel(\"order_id\")","ref":"ExPorterSDK.html#module-cancel-order"},{"type":"module","title":"Testing - ExPorterSDK","doc":"The SDK provides stub implementations for testing. Configure them in your `config/test.exs`:\n\n    config :ex_porter_sdk,\n      base_url: \"https://api.porter.in\",\n      api_key: \"your-api-key\",\n      quote_impl: ExPorterSDK.Quote.Stub,\n      order_impl: ExPorterSDK.Order.Stub\n\nOr set them temporarily in your tests:\n\n    setup do\n      previous_impls = %{\n        quote: Application.get_env(:ex_porter_sdk, :quote_impl),\n        order: Application.get_env(:ex_porter_sdk, :order_impl)\n      }\n\n      Application.put_env(:ex_porter_sdk, :quote_impl, ExPorterSDK.Quote.Stub)\n      Application.put_env(:ex_porter_sdk, :order_impl, ExPorterSDK.Order.Stub)\n\n      on_exit(fn ->\n        Application.put_env(:ex_porter_sdk, :quote_impl, previous_impls.quote)\n        Application.put_env(:ex_porter_sdk, :order_impl, previous_impls.order)\n      end)\n\n      :ok\n    end","ref":"ExPorterSDK.html#module-testing"},{"type":"module","title":"Error Handling - ExPorterSDK","doc":"All operations return tagged tuples:\n\n  * `{:ok, response}` - Successful operation with response data\n  * `{:error, reason}` - Failed operation with error details\n\nCommon error reasons include:\n  * Invalid parameters\n  * Authentication failures\n  * Network issues\n  * Resource not found\n  * Server errors","ref":"ExPorterSDK.html#module-error-handling"},{"type":"module","title":"Links - ExPorterSDK","doc":"* [GitHub](https://github.com/yatender-oktalk/ex_porter_sdk)\n  * [Documentation](https://hexdocs.pm/ex_porter_sdk)\n  * [Porter API Documentation](https://porter.in/api-docs)","ref":"ExPorterSDK.html#module-links"},{"type":"function","title":"ExPorterSDK.api_key/0","doc":"Returns the configured API key for the Porter API.","ref":"ExPorterSDK.html#api_key/0"},{"type":"function","title":"Raises - ExPorterSDK.api_key/0","doc":"RuntimeError if api_key is not configured.","ref":"ExPorterSDK.html#api_key/0-raises"},{"type":"function","title":"Examples - ExPorterSDK.api_key/0","doc":"iex> ExPorterSDK.api_key()\n    \"your-api-key\"","ref":"ExPorterSDK.html#api_key/0-examples"},{"type":"function","title":"ExPorterSDK.base_url/0","doc":"Returns the configured base URL for the Porter API.","ref":"ExPorterSDK.html#base_url/0"},{"type":"function","title":"Raises - ExPorterSDK.base_url/0","doc":"RuntimeError if base_url is not configured.","ref":"ExPorterSDK.html#base_url/0-raises"},{"type":"function","title":"Examples - ExPorterSDK.base_url/0","doc":"iex> ExPorterSDK.base_url()\n    \"https://api.porter.in\"","ref":"ExPorterSDK.html#base_url/0-examples"},{"type":"module","title":"ExPorterSDK.Config","doc":"Configuration for Porter SDK.","ref":"ExPorterSDK.Config.html"},{"type":"function","title":"ExPorterSDK.Config.api_key/0","doc":"","ref":"ExPorterSDK.Config.html#api_key/0"},{"type":"function","title":"ExPorterSDK.Config.base_url/0","doc":"","ref":"ExPorterSDK.Config.html#base_url/0"},{"type":"function","title":"ExPorterSDK.Config.get/0","doc":"","ref":"ExPorterSDK.Config.html#get/0"},{"type":"module","title":"ExPorterSDK.ErrorHandler","doc":"","ref":"ExPorterSDK.ErrorHandler.html"},{"type":"function","title":"ExPorterSDK.ErrorHandler.handle_response/1","doc":"","ref":"ExPorterSDK.ErrorHandler.html#handle_response/1"},{"type":"module","title":"ExPorterSDK.Http.Impl","doc":"HTTP client wrapper for Porter API.","ref":"ExPorterSDK.Http.Impl.html"},{"type":"function","title":"ExPorterSDK.Http.Impl.request/3","doc":"","ref":"ExPorterSDK.Http.Impl.html#request/3"},{"type":"module","title":"ExPorterSDK.Order.Impl","doc":"","ref":"ExPorterSDK.Order.Impl.html"},{"type":"function","title":"ExPorterSDK.Order.Impl.cancel/1","doc":"","ref":"ExPorterSDK.Order.Impl.html#cancel/1"},{"type":"function","title":"ExPorterSDK.Order.Impl.create/1","doc":"","ref":"ExPorterSDK.Order.Impl.html#create/1"},{"type":"function","title":"ExPorterSDK.Order.Impl.track/1","doc":"","ref":"ExPorterSDK.Order.Impl.html#track/1"},{"type":"module","title":"ExPorterSDK.Parser","doc":"Provides functions to parse fare estimate data, customer details, contact details, and addresses.","ref":"ExPorterSDK.Parser.html"},{"type":"function","title":"ExPorterSDK.Parser.parse_address/1","doc":"Parses address details from a map.","ref":"ExPorterSDK.Parser.html#parse_address/1"},{"type":"function","title":"Parameters - ExPorterSDK.Parser.parse_address/1","doc":"- map: A map containing address details or nil.","ref":"ExPorterSDK.Parser.html#parse_address/1-parameters"},{"type":"function","title":"Returns - ExPorterSDK.Parser.parse_address/1","doc":"- `{:ok, AddressLatLng.t()}` on success.\n  - `{:error, String.t()}` on failure with an error message.","ref":"ExPorterSDK.Parser.html#parse_address/1-returns"},{"type":"function","title":"ExPorterSDK.Parser.parse_contact/1","doc":"Parses contact details from a map.","ref":"ExPorterSDK.Parser.html#parse_contact/1"},{"type":"function","title":"Parameters - ExPorterSDK.Parser.parse_contact/1","doc":"- map: A map containing contact details or nil.","ref":"ExPorterSDK.Parser.html#parse_contact/1-parameters"},{"type":"function","title":"Returns - ExPorterSDK.Parser.parse_contact/1","doc":"- `{:ok, ContactDetails.t()}` on success.\n  - `{:error, String.t()}` on failure with an error message.","ref":"ExPorterSDK.Parser.html#parse_contact/1-returns"},{"type":"function","title":"ExPorterSDK.Parser.parse_customer/1","doc":"Parses customer details from a map.","ref":"ExPorterSDK.Parser.html#parse_customer/1"},{"type":"function","title":"Parameters - ExPorterSDK.Parser.parse_customer/1","doc":"- map: A map containing customer details or nil.","ref":"ExPorterSDK.Parser.html#parse_customer/1-parameters"},{"type":"function","title":"Returns - ExPorterSDK.Parser.parse_customer/1","doc":"- `{:ok, CustomerDetails.t()}` on success.\n  - `{:error, String.t()}` on failure with an error message.","ref":"ExPorterSDK.Parser.html#parse_customer/1-returns"},{"type":"function","title":"ExPorterSDK.Parser.parse_fare_estimate/1","doc":"Parses fare estimate data from a map.","ref":"ExPorterSDK.Parser.html#parse_fare_estimate/1"},{"type":"function","title":"Parameters - ExPorterSDK.Parser.parse_fare_estimate/1","doc":"- map: A map containing fare estimate data or nil.","ref":"ExPorterSDK.Parser.html#parse_fare_estimate/1-parameters"},{"type":"function","title":"Returns - ExPorterSDK.Parser.parse_fare_estimate/1","doc":"- `FareEstimateRequest.t()` on success.\n  - `{:error, String.t()}` on failure with an error message.","ref":"ExPorterSDK.Parser.html#parse_fare_estimate/1-returns"},{"type":"module","title":"ExPorterSDK.Protocols","doc":"","ref":"ExPorterSDK.Protocols.html"},{"type":"module","title":"ExPorterSDK.Protocols.Implementations.AutoGenerated","doc":"Auto-generated protocol implementations for non-nested structures.","ref":"ExPorterSDK.Protocols.Implementations.AutoGenerated.html"},{"type":"module","title":"ExPorterSDK.Protocols.Implementations.Mappable","doc":"Protocol implementation for mappable structs.","ref":"ExPorterSDK.Protocols.Implementations.Mappable.html"},{"type":"module","title":"ExPorterSDK.Protocols.Implementations.Structable","doc":"This module provides protocol implementations for structs that are\n`TypedStruct` compliant.","ref":"ExPorterSDK.Protocols.Implementations.Structable.html"},{"type":"protocol","title":"ExPorterSDK.Protocols.Mappable","doc":"","ref":"ExPorterSDK.Protocols.Mappable.html"},{"type":"function","title":"ExPorterSDK.Protocols.Mappable.to_map/1","doc":"Converts a struct to a map, handling nested structures","ref":"ExPorterSDK.Protocols.Mappable.html#to_map/1"},{"type":"type","title":"ExPorterSDK.Protocols.Mappable.t/0","doc":"All the types that implement this protocol.","ref":"ExPorterSDK.Protocols.Mappable.html#t:t/0"},{"type":"module","title":"ExPorterSDK.Protocols.ProtocolGenerator","doc":"Generates a default protocol implementations for non-nested structures.","ref":"ExPorterSDK.Protocols.ProtocolGenerator.html"},{"type":"protocol","title":"ExPorterSDK.Protocols.Structable","doc":"","ref":"ExPorterSDK.Protocols.Structable.html"},{"type":"function","title":"ExPorterSDK.Protocols.Structable.from_map/1","doc":"Converts a map to a struct, handling nested structures","ref":"ExPorterSDK.Protocols.Structable.html#from_map/1"},{"type":"type","title":"ExPorterSDK.Protocols.Structable.t/0","doc":"All the types that implement this protocol.","ref":"ExPorterSDK.Protocols.Structable.html#t:t/0"},{"type":"protocol","title":"ExPorterSDK.Protocols.Validatable","doc":"","ref":"ExPorterSDK.Protocols.Validatable.html"},{"type":"function","title":"ExPorterSDK.Protocols.Validatable.validate/1","doc":"Validates the structure and returns :ok or {:error, reason}","ref":"ExPorterSDK.Protocols.Validatable.html#validate/1"},{"type":"type","title":"ExPorterSDK.Protocols.Validatable.t/0","doc":"All the types that implement this protocol.","ref":"ExPorterSDK.Protocols.Validatable.html#t:t/0"},{"type":"module","title":"ExPorterSDK.Quote.Impl","doc":"","ref":"ExPorterSDK.Quote.Impl.html"},{"type":"function","title":"ExPorterSDK.Quote.Impl.get_quote/1","doc":"","ref":"ExPorterSDK.Quote.Impl.html#get_quote/1"},{"type":"module","title":"ExPorterSDK.Structs.Types.Address","doc":"Represents an address.","ref":"ExPorterSDK.Structs.Types.Address.html"},{"type":"type","title":"ExPorterSDK.Structs.Types.Address.t/0","doc":"","ref":"ExPorterSDK.Structs.Types.Address.html#t:t/0"},{"type":"module","title":"ExPorterSDK.Structs.Types.AddressDetails","doc":"Represents the details of an address.","ref":"ExPorterSDK.Structs.Types.AddressDetails.html"},{"type":"type","title":"ExPorterSDK.Structs.Types.AddressDetails.t/0","doc":"","ref":"ExPorterSDK.Structs.Types.AddressDetails.html#t:t/0"},{"type":"module","title":"ExPorterSDK.Structs.Types.AddressLatLng","doc":"Geographic coordinates structure.","ref":"ExPorterSDK.Structs.Types.AddressLatLng.html"},{"type":"function","title":"ExPorterSDK.Structs.Types.AddressLatLng.from_map/1","doc":"","ref":"ExPorterSDK.Structs.Types.AddressLatLng.html#from_map/1"},{"type":"function","title":"ExPorterSDK.Structs.Types.AddressLatLng.to_map/1","doc":"","ref":"ExPorterSDK.Structs.Types.AddressLatLng.html#to_map/1"},{"type":"function","title":"ExPorterSDK.Structs.Types.AddressLatLng.validate/1","doc":"","ref":"ExPorterSDK.Structs.Types.AddressLatLng.html#validate/1"},{"type":"type","title":"ExPorterSDK.Structs.Types.AddressLatLng.t/0","doc":"","ref":"ExPorterSDK.Structs.Types.AddressLatLng.html#t:t/0"},{"type":"module","title":"ExPorterSDK.Structs.Types.Config","doc":"Configuration struct for Porter SDK.","ref":"ExPorterSDK.Structs.Types.Config.html"},{"type":"function","title":"ExPorterSDK.Structs.Types.Config.to_map/1","doc":"","ref":"ExPorterSDK.Structs.Types.Config.html#to_map/1"},{"type":"function","title":"ExPorterSDK.Structs.Types.Config.validate/1","doc":"","ref":"ExPorterSDK.Structs.Types.Config.html#validate/1"},{"type":"type","title":"ExPorterSDK.Structs.Types.Config.t/0","doc":"","ref":"ExPorterSDK.Structs.Types.Config.html#t:t/0"},{"type":"module","title":"ExPorterSDK.Structs.Types.ContactDetails","doc":"","ref":"ExPorterSDK.Structs.Types.ContactDetails.html"},{"type":"function","title":"ExPorterSDK.Structs.Types.ContactDetails.from_map/1","doc":"","ref":"ExPorterSDK.Structs.Types.ContactDetails.html#from_map/1"},{"type":"function","title":"ExPorterSDK.Structs.Types.ContactDetails.to_map/1","doc":"","ref":"ExPorterSDK.Structs.Types.ContactDetails.html#to_map/1"},{"type":"function","title":"ExPorterSDK.Structs.Types.ContactDetails.validate/1","doc":"","ref":"ExPorterSDK.Structs.Types.ContactDetails.html#validate/1"},{"type":"type","title":"ExPorterSDK.Structs.Types.ContactDetails.t/0","doc":"","ref":"ExPorterSDK.Structs.Types.ContactDetails.html#t:t/0"},{"type":"module","title":"ExPorterSDK.Structs.Types.CreateOrderRequest","doc":"Represents a request to create an order.","ref":"ExPorterSDK.Structs.Types.CreateOrderRequest.html"},{"type":"type","title":"ExPorterSDK.Structs.Types.CreateOrderRequest.t/0","doc":"","ref":"ExPorterSDK.Structs.Types.CreateOrderRequest.html#t:t/0"},{"type":"module","title":"ExPorterSDK.Structs.Types.CustomerDetails","doc":"","ref":"ExPorterSDK.Structs.Types.CustomerDetails.html"},{"type":"function","title":"ExPorterSDK.Structs.Types.CustomerDetails.from_map/1","doc":"","ref":"ExPorterSDK.Structs.Types.CustomerDetails.html#from_map/1"},{"type":"function","title":"ExPorterSDK.Structs.Types.CustomerDetails.to_map/1","doc":"","ref":"ExPorterSDK.Structs.Types.CustomerDetails.html#to_map/1"},{"type":"function","title":"ExPorterSDK.Structs.Types.CustomerDetails.validate/1","doc":"","ref":"ExPorterSDK.Structs.Types.CustomerDetails.html#validate/1"},{"type":"type","title":"ExPorterSDK.Structs.Types.CustomerDetails.t/0","doc":"","ref":"ExPorterSDK.Structs.Types.CustomerDetails.html#t:t/0"},{"type":"module","title":"ExPorterSDK.Structs.Types.FareEstimateRequest","doc":"","ref":"ExPorterSDK.Structs.Types.FareEstimateRequest.html"},{"type":"function","title":"ExPorterSDK.Structs.Types.FareEstimateRequest.from_map/1","doc":"","ref":"ExPorterSDK.Structs.Types.FareEstimateRequest.html#from_map/1"},{"type":"function","title":"ExPorterSDK.Structs.Types.FareEstimateRequest.to_map/1","doc":"","ref":"ExPorterSDK.Structs.Types.FareEstimateRequest.html#to_map/1"},{"type":"function","title":"ExPorterSDK.Structs.Types.FareEstimateRequest.validate_struct/1","doc":"","ref":"ExPorterSDK.Structs.Types.FareEstimateRequest.html#validate_struct/1"},{"type":"type","title":"ExPorterSDK.Structs.Types.FareEstimateRequest.t/0","doc":"","ref":"ExPorterSDK.Structs.Types.FareEstimateRequest.html#t:t/0"},{"type":"module","title":"ExPorterSDK.Webhook","doc":"","ref":"ExPorterSDK.Webhook.html"},{"type":"function","title":"ExPorterSDK.Webhook.verify_webhook/2","doc":"","ref":"ExPorterSDK.Webhook.html#verify_webhook/2"},{"type":"module","title":"ExPorterSDK.Webhook.Impl","doc":"Handles webhook-related operations","ref":"ExPorterSDK.Webhook.Impl.html"},{"type":"function","title":"ExPorterSDK.Webhook.Impl.verify_webhook/2","doc":"","ref":"ExPorterSDK.Webhook.Impl.html#verify_webhook/2"},{"type":"module","title":"ExPorterSDK.Order","doc":"Order operations dispatcher based on environment.\n\nThis module provides functions to create, track, and cancel orders\nin the Porter API. It dynamically dispatches to the appropriate\nimplementation based on the application configuration.","ref":"ExPorterSDK.Order.html"},{"type":"module","title":"Functions - ExPorterSDK.Order","doc":"- `create/1`: Create a new order.\n- `track/1`: Retrieve the status of an existing order.\n- `cancel/2`: Cancel an existing order.","ref":"ExPorterSDK.Order.html#module-functions"},{"type":"module","title":"Example Usage - ExPorterSDK.Order","doc":"iex> ExPorterSDK.Order.create(%{pickup_details: ..., drop_details: ..., delivery_instructions: ...})\n    {:ok, order_response}\n\n    iex> ExPorterSDK.Order.track(\"order_id\")\n    {:ok, order_status}\n\n    iex> ExPorterSDK.Order.cancel(\"order_id\", \"Customer request\")\n    {:ok, cancellation_response}","ref":"ExPorterSDK.Order.html#module-example-usage"},{"type":"function","title":"ExPorterSDK.Order.cancel/1","doc":"Cancel an order.\n\nThis function cancels an existing order based on its order ID.","ref":"ExPorterSDK.Order.html#cancel/1"},{"type":"function","title":"Parameters - ExPorterSDK.Order.cancel/1","doc":"- `order_id`: The unique identifier of the order to be canceled.\n- `reason`: A string specifying the reason for cancellation.","ref":"ExPorterSDK.Order.html#cancel/1-parameters"},{"type":"function","title":"Returns - ExPorterSDK.Order.cancel/1","doc":"- `{:ok, cancellation_response}`: On success, returns the cancellation response.\n- `{:error, reason}`: On failure, returns an error reason.","ref":"ExPorterSDK.Order.html#cancel/1-returns"},{"type":"function","title":"Example - ExPorterSDK.Order.cancel/1","doc":"iex> ExPorterSDK.Order.cancel(\"order_id\")\n    {:ok, %{message: \"Order canceled successfully\"}}","ref":"ExPorterSDK.Order.html#cancel/1-example"},{"type":"function","title":"ExPorterSDK.Order.create/1","doc":"Create an order.\n\nThis function takes a map of parameters required to create an order.\nIt delegates the call to the appropriate implementation.","ref":"ExPorterSDK.Order.html#create/1"},{"type":"function","title":"Parameters - ExPorterSDK.Order.create/1","doc":"- `params`: A map containing the necessary details for the order\n  including `pickup_details`, `drop_details`, and `delivery_instructions`.","ref":"ExPorterSDK.Order.html#create/1-parameters"},{"type":"function","title":"Returns - ExPorterSDK.Order.create/1","doc":"- `{:ok, response}`: On success, returns the response from the API.\n- `{:error, reason}`: On failure, returns an error reason.","ref":"ExPorterSDK.Order.html#create/1-returns"},{"type":"function","title":"Example - ExPorterSDK.Order.create/1","doc":"iex> ExPorterSDK.Order.create(%{pickup_details: ..., drop_details: ..., delivery_instructions: ...})\n    {:ok, %{order_id: \"12345\", status: \"created\"}}","ref":"ExPorterSDK.Order.html#create/1-example"},{"type":"function","title":"ExPorterSDK.Order.track/1","doc":"Track an order.\n\nThis function retrieves the current status of a specific order.","ref":"ExPorterSDK.Order.html#track/1"},{"type":"function","title":"Parameters - ExPorterSDK.Order.track/1","doc":"- `order_id`: The unique identifier of the order to be tracked.","ref":"ExPorterSDK.Order.html#track/1-parameters"},{"type":"function","title":"Returns - ExPorterSDK.Order.track/1","doc":"- `{:ok, order_status}`: On success, returns the current status of the order.\n- `{:error, reason}`: On failure, returns an error reason.","ref":"ExPorterSDK.Order.html#track/1-returns"},{"type":"function","title":"Example - ExPorterSDK.Order.track/1","doc":"iex> ExPorterSDK.Order.track(\"order_id\")\n    {:ok, %{status: \"in_transit\", estimated_delivery: \"2023-10-20T10:00:00Z\"}}","ref":"ExPorterSDK.Order.html#track/1-example"},{"type":"module","title":"ExPorterSDK.Quote","doc":"Quote operations dispatcher based on environment.","ref":"ExPorterSDK.Quote.html"},{"type":"module","title":"Example - ExPorterSDK.Quote","doc":"params = %{\n  pickup_details: %{lat: 12.909728534457143, lng: 77.6001397394293},\n  drop_details: %{lat: 12.89795704454522, lng: 77.62119799020186},\n  customer: %{\n    name: \"Porter Test User\",\n    mobile: %{number: \"7678139714\", country_code: \"+91\"}\n  }\n}\n\n{:ok, quote} = ExPorterSDK.Quote.get_quote(params)","ref":"ExPorterSDK.Quote.html#module-example"},{"type":"behaviour","title":"ExPorterSDK.Behaviours.Order","doc":"","ref":"ExPorterSDK.Behaviours.Order.html"},{"type":"callback","title":"ExPorterSDK.Behaviours.Order.cancel/1","doc":"","ref":"ExPorterSDK.Behaviours.Order.html#c:cancel/1"},{"type":"callback","title":"ExPorterSDK.Behaviours.Order.create/1","doc":"","ref":"ExPorterSDK.Behaviours.Order.html#c:create/1"},{"type":"callback","title":"ExPorterSDK.Behaviours.Order.track/1","doc":"","ref":"ExPorterSDK.Behaviours.Order.html#c:track/1"},{"type":"behaviour","title":"ExPorterSDK.Behaviours.Quote","doc":"","ref":"ExPorterSDK.Behaviours.Quote.html"},{"type":"callback","title":"ExPorterSDK.Behaviours.Quote.get_quote/1","doc":"","ref":"ExPorterSDK.Behaviours.Quote.html#c:get_quote/1"},{"type":"module","title":"ExPorterSDK.Order.Stub","doc":"Stub implementation of Order operations for testing.","ref":"ExPorterSDK.Order.Stub.html"},{"type":"module","title":"ExPorterSDK.Quote.Stub","doc":"Stub implementation of Quote operations for testing.","ref":"ExPorterSDK.Quote.Stub.html"},{"type":"extras","title":"ExPorterSDK","doc":"# ExPorterSDK\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_porter_sdk.svg)](https://hex.pm/packages/ex_porter_sdk)\n[![Docs](https://img.shields.io/badge/hex-docs-green.svg)](https://hexdocs.pm/ex_porter_sdk)\n[![License](https://img.shields.io/badge/license-MIT-blue.svg)](LICENSE.md)\n\nAn Elixir SDK for [Porter](https://porter.in)'s delivery API, providing a simple and reliable way to integrate Porter's logistics services into your Elixir applications.","ref":"readme.html"},{"type":"extras","title":"Features - ExPorterSDK","doc":"- 🚚 Get delivery quotes based on locations\n- 📦 Create and manage delivery orders\n- 🔍 Track order status in real-time\n- ⚡ Simple and intuitive API\n- 🧪 Comprehensive test coverage\n- 📚 Well-documented codebase","ref":"readme.html#features"},{"type":"extras","title":"Installation - ExPorterSDK","doc":"Add `ex_porter_sdk` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_porter_sdk, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - ExPorterSDK","doc":"Configure the SDK in your `config.exs`:\n\n```elixir\nconfig :ex_porter_sdk,\n  base_url: System.get_env(\"PORTER_BASE_URL\", \"https://api.porter.in\"),\n  api_key: System.get_env(\"PORTER_API_KEY\")\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Quick Start - ExPorterSDK","doc":"","ref":"readme.html#quick-start"},{"type":"extras","title":"Get Delivery Quote - ExPorterSDK","doc":"```elixir\nparams = %{\n  pickup_details: %{lat: 12.909728534457143, lng: 77.6001397394293},\n  drop_details: %{lat: 12.89795704454522, lng: 77.62119799020186},\n  customer: %{\n    name: \"Test User\",\n    mobile: %{number: \"7678139714\", country_code: \"+91\"}\n  }\n}\n\n{:ok, response} = ExPorterSDK.Quote.get_quote(params)\n```","ref":"readme.html#get-delivery-quote"},{"type":"extras","title":"Create Order - ExPorterSDK","doc":"```elixir\norder_params = %{\n  request_id: \"unique-request-id\",\n  pickup_details: %{\n    address: %{\n      apartment_address: \"27\",\n      street_address1: \"Main Street\",\n      city: \"Bengaluru\",\n      state: \"Karnataka\",\n      pincode: \"560029\",\n      country: \"India\",\n      lat: 12.939391726766775,\n      lng: 77.62629462844717,\n      contact_details: %{\n        name: \"Test User\",\n        phone_number: \"+911234567890\"\n      }\n    }\n  },\n  drop_details: %{\n    # Similar structure as pickup_details\n  }\n}\n\n{:ok, response} = ExPorterSDK.Order.create(order_params)\n```","ref":"readme.html#create-order"},{"type":"extras","title":"Track Order - ExPorterSDK","doc":"```elixir\n{:ok, status} = ExPorterSDK.Order.track(\"order_id\")\n```","ref":"readme.html#track-order"},{"type":"extras","title":"Cancel Order - ExPorterSDK","doc":"```elixir\n{:ok, response} = ExPorterSDK.Order.cancel(\"order_id\")\n```","ref":"readme.html#cancel-order"},{"type":"extras","title":"Documentation - ExPorterSDK","doc":"Detailed documentation is available at [https://hexdocs.pm/ex_porter_sdk](https://hexdocs.pm/ex_porter_sdk).","ref":"readme.html#documentation"},{"type":"extras","title":"Testing - ExPorterSDK","doc":"The SDK includes comprehensive tests. Run them with:\n\n```bash\nmix test\n```\n\nFor development and testing, use the provided stubs:\n\n```elixir\n# config/test.exs\nconfig :ex_porter_sdk,\n  quote_impl: ExPorterSDK.Quote.Stub,\n  order_impl: ExPorterSDK.Order.Stub\n```","ref":"readme.html#testing"},{"type":"extras","title":"Contributing - ExPorterSDK","doc":"We appreciate all contributions. See our [Contributing Guide](CONTRIBUTING.md) for details.","ref":"readme.html#contributing"},{"type":"extras","title":"License - ExPorterSDK","doc":"This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Support - ExPorterSDK","doc":"- Open an issue for bug reports or feature requests\n- For detailed questions, please email `yatender[dot]nitk[at]gmail[dot]com`","ref":"readme.html#support"},{"type":"extras","title":"Acknowledgments - ExPorterSDK","doc":"- [Porter API Documentation](https://porter.in/api-docs)\n- All contributors to this project","ref":"readme.html#acknowledgments"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.0 (2024-01-24) - Changelog","doc":"","ref":"changelog.html#v0-1-0-2024-01-24"},{"type":"extras","title":"First Release - Changelog","doc":"* Initial implementation of Porter SDK\n* Features include:\n  * Get delivery quotes\n  * Create orders\n  * Track orders\n  * Cancel orders\n* Includes test helpers and stubs\n* Complete documentation","ref":"changelog.html#first-release"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Yatender Singh Suman\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}